==> openGion7.2.8.0_dev.zip: uap/webapps/ge/db/DERBY/sql/install/01_TABLE/GE34S.sql <==
/****************************************************************************/
/* GE34 ( 宛先ﾃｰﾌﾞﾙ )                                                       */
/*                                                                          */
/* Created : 2018/09/28 16:03:46                                            */
/****************************************************************************/

CREATE TABLE GE34 (
   YKNO     INTEGER             DEFAULT 0   NOT NULL                                                                                                        /*  10 要求NO   */
 , GROUP_ID VARCHAR (  20 )                                                                                                                                 /*  20 ｸﾞﾙｰﾌﾟID */
 , DST_ID   VARCHAR (  10 )                 NOT NULL                                                                                                        /*  30 社員番号 */
 , DST_NAME VARCHAR ( 100 )                                                                                                                                 /*  40 名前     */
 , DST_ADDR VARCHAR ( 100 )                                                                                                                                 /*  50 ﾒｰﾙｱﾄﾞﾚｽ */
 , DST_KBN  VARCHAR (   1 )                 NOT NULL                                                                                                        /*  60 送信区分 */
 , UNIQ     BIGINT                          NOT NULL     generated always as identity (start with 1, increment by 1),constraint GE34 primary key(UNIQ)      /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ      VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                                                                        /* 810 状態ﾌﾗｸﾞ */
 , DYSET    VARCHAR (  14 )                                                                                                                                 /* 820 登録日時 */
 , PGSET    VARCHAR (  10 )                                                                                                                                 /* 830 作成PG   */
 , PGPSET   VARCHAR (  10 )                                                                                                                                 /* 840 作成親PG */
 , USRSET   VARCHAR (  10 )                                                                                                                                 /* 850 作成者   */
 , DYUPD    VARCHAR (  14 )                                                                                                                                 /* 860 更新日時 */
 , PGUPD    VARCHAR (  10 )                                                                                                                                 /* 870 更新PG   */
 , PGPUPD   VARCHAR (  10 )                                                                                                                                 /* 880 更新親PG */
 , USRUPD   VARCHAR (  10 )                                                                                                                                 /* 890 更新者   */
);

==> openGion7.3.1.3_dev.zip: uap/webapps/ge/db/DERBY/sql/install/01_TABLE/GE34S.sql <==
/****************************************************************************/
/* GE34 ( 宛先ﾃｰﾌﾞﾙ )                                                       */
/*                                                                          */
/* Created : 2020/12/16 08:14:26                                            */
/****************************************************************************/

CREATE TABLE GE34 (
   YKNO     INTEGER             DEFAULT 0   NOT NULL                                                                                                        /*  10 要求NO   */
 , GROUP_ID VARCHAR (  20 )                                                                                                                                 /*  20 ｸﾞﾙｰﾌﾟID */
 , DST_ID   VARCHAR (  10 )                 NOT NULL                                                                                                        /*  30 社員番号 */
 , DST_NAME VARCHAR ( 100 )                                                                                                                                 /*  40 名前     */
 , DST_ADDR VARCHAR ( 100 )                                                                                                                                 /*  50 ﾒｰﾙｱﾄﾞﾚｽ */
 , DST_KBN  VARCHAR (   1 )                 NOT NULL                                                                                                        /*  60 送信区分 */
 , UNIQ     BIGINT                          NOT NULL     generated always as identity (start with 1, increment by 1),constraint GE34 primary key(UNIQ)      /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ      VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                                                                        /* 810 状態ﾌﾗｸﾞ */
 , DYSET    VARCHAR (  14 )                                                                                                                                 /* 820 作成日時 */
 , PGSET    VARCHAR (  10 )                                                                                                                                 /* 830 作成PG   */
 , PGPSET   VARCHAR (  10 )                                                                                                                                 /* 840 作成親PG */
 , USRSET   VARCHAR (  10 )                                                                                                                                 /* 850 作成者   */
 , DYUPD    VARCHAR (  14 )                                                                                                                                 /* 860 更新日時 */
 , PGUPD    VARCHAR (  10 )                                                                                                                                 /* 870 更新PG   */
 , PGPUPD   VARCHAR (  10 )                                                                                                                                 /* 880 更新親PG */
 , USRUPD   VARCHAR (  10 )                                                                                                                                 /* 890 更新者   */
);
